==> interactik-collaboratif-calendar-4.6.11.2-sources.jar: fr/toutatice/services/calendar/event/edition/portlet/repository/command/AbstractInteractikCalendarEventCommand.java <==
package fr.toutatice.services.calendar.event.edition.portlet.repository.command;

import static fr.toutatice.services.calendar.common.InteractikCalendarConstant.DEPARTEMENT_PROPERTY;
import static fr.toutatice.services.calendar.common.InteractikCalendarConstant.DATE_DEBUT_INSCRIPTION_PROPERTY;
import static fr.toutatice.services.calendar.common.InteractikCalendarConstant.DATE_FIN_INSCRIPTION_PROPERTY;
import static fr.toutatice.services.calendar.common.InteractikCalendarConstant.VILLE_PROPERTY;
import static fr.toutatice.services.calendar.common.InteractikCalendarConstant.URL_INSCRIPTION_PROPERTY;

import java.io.File;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.SortedSet;
import java.util.TimeZone;
import java.util.TreeSet;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.nuxeo.ecm.automation.client.adapters.DocumentService;
import org.nuxeo.ecm.automation.client.model.Blob;
import org.nuxeo.ecm.automation.client.model.Blobs;
import org.nuxeo.ecm.automation.client.model.Document;
import org.nuxeo.ecm.automation.client.model.FileBlob;
import org.nuxeo.ecm.automation.client.model.PropertyMap;
import org.osivia.services.calendar.common.model.Attachment;
import org.osivia.services.calendar.common.model.CalendarColor;
import org.osivia.services.calendar.event.edition.portlet.model.comparator.IndexComparator;
import org.osivia.services.calendar.event.edition.portlet.repository.CalendarEventEditionRepository;
import org.springframework.beans.factory.annotation.Autowired;

import fr.toutatice.portail.cms.nuxeo.api.INuxeoCommand;
import fr.toutatice.services.calendar.common.model.InteractikCalendarColor;
import fr.toutatice.services.calendar.event.edition.portlet.model.InteractikCalendarEventEditionForm;

/**
 * Calendar event edition Nuxeo command abstract super-class.
 * 
 * @author Cédric Krommenhoek
 * @see INuxeoCommand
 */
public abstract class AbstractInteractikCalendarEventCommand implements INuxeoCommand {
	
    /** Date format pattern. */
    private static final String DATE_FORMAT_PATTERN = "dd/MM/yyyy";
	
    /** Blob index comparator. */
    @Autowired
    private IndexComparator indexComparator;
    /** Date format. */
    protected final DateFormat dateFormat;
    
    
    /**
     * Constructor.
     */
    public AbstractInteractikCalendarEventCommand() {
        super();
        
        // Date format
        this.dateFormat = new SimpleDateFormat(DATE_FORMAT_PATTERN);
        this.dateFormat.setTimeZone(TimeZone.getTimeZone("GMT"));
    }


    /**
     * {@inheritDoc}
     */
    @Override
    public String getId() {
        return null;
    }


    /**
     * Get Nuxeo document properties.
     * 
     * @param form calendar event edition form
     * @return properties
     * @throws ParseException 
     */
    protected PropertyMap getProperties(InteractikCalendarEventEditionForm form) throws ParseException {
        // Color identifier
        String colorId;
        if (form.getColor() == null) {
            colorId = null;
        } else {
            colorId = ((InteractikCalendarColor) form.getColor()).getId();
        }
        // Color
        CalendarColor color = CalendarColor.fromId(colorId);
        if (color.equals(form.getCalendarColor())) {
            colorId = null;
        }


        // Document properties
        PropertyMap properties = new PropertyMap();
        properties.set(CalendarEventEditionRepository.TITLE_PROPERTY, form.getTitle());
        properties.set(CalendarEventEditionRepository.START_DATE_PROPERTY, form.getStartDate());
        properties.set(CalendarEventEditionRepository.END_DATE_PROPERTY, form.getEndDate());
        properties.set(CalendarEventEditionRepository.ALL_DAY_PROPERTY, form.isAllDay());
        properties.set(CalendarEventEditionRepository.LOCATION_PROPERTY, form.getLocation());
        properties.set(CalendarEventEditionRepository.COLOR_PROPERTY, colorId);
        properties.set(CalendarEventEditionRepository.DESCRIPTION_PROPERTY, form.getDescription());
        properties.set(DEPARTEMENT_PROPERTY, form.getDepartement());
        properties.set(VILLE_PROPERTY, form.getVille());
        properties.set(DATE_DEBUT_INSCRIPTION_PROPERTY, this.parseDate(form.getStringDebutInscription()));
        properties.set(DATE_FIN_INSCRIPTION_PROPERTY, this.parseDate(form.getStringFinInscription()));
        properties.set(URL_INSCRIPTION_PROPERTY, form.getUrlInscription());

        return properties;
    }


    /**
     * Set attachments.
     *
     * @param documentService Nuxeo document service
     * @param document Nuxeo document
     * @param attachments attachments
     * @throws Exception
     */
    protected void setAttachments(DocumentService documentService, Document document, InteractikCalendarEventEditionForm form) throws Exception {
        // Attachment files
        List<Attachment> files = form.getAttachments().getFiles();

        if (CollectionUtils.isNotEmpty(files)) {
            // Remove blobs
            SortedSet<Integer> removedIndexes = new TreeSet<>(this.indexComparator);
            for (Attachment file : files) {
                if (file.isDeleted() && (file.getIndex() != null)) {
                    removedIndexes.add(file.getIndex());
                }
            }
            for (Integer index : removedIndexes) {
                StringBuilder xpath = new StringBuilder();
                xpath.append(CalendarEventEditionRepository.ATTACHMENTS_PROPERTY);
                xpath.append("/item[");
                xpath.append(index);
                xpath.append("]");

                documentService.removeBlob(document, xpath.toString());
            }


            // Blobs
            List<Blob> blobs = new ArrayList<>(files.size());

            for (Attachment file : files) {
                // Temporary file
                File temporaryFile = file.getTemporaryFile();

                if (!file.isDeleted() && (temporaryFile != null)) {
                    // File name
                    String fileName = file.getTemporaryFileName();
                    // Mime type
                    String mimeType = file.getTemporaryMimeType().getBaseType();

                    // File blob
                    Blob blob = new FileBlob(temporaryFile, fileName, mimeType);

                    blobs.add(blob);
                }
            }

            if (!blobs.isEmpty()) {
                documentService.setBlobs(document, new Blobs(blobs), CalendarEventEditionRepository.ATTACHMENTS_PROPERTY);

                // Delete temporary files
                for (Attachment file : files) {
                    if (file.getTemporaryFile() != null) {
                        file.getTemporaryFile().delete();
                    }
                }
            }
        }
    }
    
    /**
     * Parse formatted date.
     * 
     * @param date formatted date
     * @return date object
     * @throws ParseException
     */
    private Date parseDate(String strDate) throws ParseException {
        StringBuilder source = new StringBuilder();
        source.append(StringUtils.trimToEmpty(strDate));
        Date date = null;
        if (source.length()>0) date = this.dateFormat.parse(source.toString());
        return date;
    }

}

==> interactik-collaboratif-calendar-4.7.7-sources.jar: fr/toutatice/services/calendar/event/edition/portlet/repository/command/AbstractInteractikCalendarEventCommand.java <==
package fr.toutatice.services.calendar.event.edition.portlet.repository.command;

import java.io.File;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.SortedSet;
import java.util.TimeZone;
import java.util.TreeSet;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.nuxeo.ecm.automation.client.adapters.DocumentService;
import org.nuxeo.ecm.automation.client.model.Blob;
import org.nuxeo.ecm.automation.client.model.Blobs;
import org.nuxeo.ecm.automation.client.model.Document;
import org.nuxeo.ecm.automation.client.model.FileBlob;
import org.nuxeo.ecm.automation.client.model.PropertyMap;
import org.osivia.services.calendar.common.model.Attachment;
import org.osivia.services.calendar.common.model.CalendarColor;
import org.osivia.services.calendar.event.edition.portlet.model.comparator.IndexComparator;
import org.osivia.services.calendar.event.edition.portlet.repository.CalendarEventEditionRepository;
import org.springframework.beans.factory.annotation.Autowired;

import fr.toutatice.portail.cms.nuxeo.api.INuxeoCommand;
import fr.toutatice.services.calendar.common.InteractikCalendarConstant;
import fr.toutatice.services.calendar.common.model.InteractikCalendarColor;
import fr.toutatice.services.calendar.event.edition.portlet.model.InteractikCalendarEventEditionForm;

/**
 * Calendar event edition Nuxeo command abstract super-class.
 * 
 * @author Cédric Krommenhoek
 * @see INuxeoCommand
 */
public abstract class AbstractInteractikCalendarEventCommand implements INuxeoCommand {
	
    /** Date format pattern. */
    private static final String DATE_FORMAT_PATTERN = "dd/MM/yyyy";
	
    /** Blob index comparator. */
    @Autowired
    private IndexComparator indexComparator;
    /** Date format. */
    protected final DateFormat dateFormat;
    
    
    /**
     * Constructor.
     */
    public AbstractInteractikCalendarEventCommand() {
        super();
        
        // Date format
        this.dateFormat = new SimpleDateFormat(DATE_FORMAT_PATTERN);
        this.dateFormat.setTimeZone(TimeZone.getTimeZone("GMT"));
    }


    /**
     * {@inheritDoc}
     */
    @Override
    public String getId() {
        return null;
    }


    /**
     * Get Nuxeo document properties.
     * 
     * @param form calendar event edition form
     * @return properties
     * @throws ParseException 
     */
    protected PropertyMap getProperties(InteractikCalendarEventEditionForm form) throws ParseException {
        // Color identifier
        String colorId;
        if (form.getColor() == null) {
            colorId = null;
        } else {
            colorId = ((InteractikCalendarColor) form.getColor()).getId();
        }
        // Color
        CalendarColor color = CalendarColor.fromId(colorId);
        if (color.equals(form.getCalendarColor())) {
            colorId = null;
        }


        // Document properties
        PropertyMap properties = new PropertyMap();
        properties.set(CalendarEventEditionRepository.TITLE_PROPERTY, form.getTitle());
        properties.set(CalendarEventEditionRepository.START_DATE_PROPERTY, form.getStartDate());
        properties.set(CalendarEventEditionRepository.END_DATE_PROPERTY, form.getEndDate());
        properties.set(CalendarEventEditionRepository.ALL_DAY_PROPERTY, form.isAllDay());
        properties.set(CalendarEventEditionRepository.LOCATION_PROPERTY, form.getLocation());
        properties.set(CalendarEventEditionRepository.COLOR_PROPERTY, colorId);
        properties.set(CalendarEventEditionRepository.DESCRIPTION_PROPERTY, form.getDescription());
        properties.set(InteractikCalendarConstant.DEPARTEMENT_PROPERTY, form.getDepartement());
        properties.set(InteractikCalendarConstant.VILLE_PROPERTY, form.getVille());
        properties.set(InteractikCalendarConstant.DATE_DEBUT_INSCRIPTION_PROPERTY, this.parseDate(form.getStringDebutInscription()));
        properties.set(InteractikCalendarConstant.DATE_FIN_INSCRIPTION_PROPERTY, this.parseDate(form.getStringFinInscription()));
        properties.set(InteractikCalendarConstant.URL_INSCRIPTION_PROPERTY, form.getUrlInscription());

        // Organisateurs
        List<String> organisateurs = form.getInteractik().getOrganisateurs();
        properties.set(InteractikCalendarConstant.ORGANISATEURS_PROPERTY, StringUtils.join(organisateurs, ","));
        // Pôles disciplinaires
        List<String> polesDisciplinaires = form.getInteractik().getPolesDisciplinaires();
        properties.set(InteractikCalendarConstant.POLES_DISCIPLINAIRES_PROPERTY, StringUtils.join(polesDisciplinaires, ","));
        // Thèmes
        List<String> themes = form.getInteractik().getThemes();
        properties.set(InteractikCalendarConstant.THEMES_PROPERTY, StringUtils.join(themes, ","));
        // Niveaux
        List<String> niveaux = form.getInteractik().getNiveaux();
        properties.set(InteractikCalendarConstant.NIVEAUX_PROPERTY, StringUtils.join(niveaux, ","));
        // Contenus
        List<String> contenus = form.getInteractik().getContenus();
        properties.set(InteractikCalendarConstant.CONTENUS_PROPERTY, StringUtils.join(contenus, ","));
        // Repères DNE
        List<String> reperesDne = form.getInteractik().getReperesDne();
        properties.set(InteractikCalendarConstant.REPERES_DNE_PROPERTY, StringUtils.join(reperesDne, ","));

        return properties;
    }


    /**
     * Set attachments.
     *
     * @param documentService Nuxeo document service
     * @param document Nuxeo document
     * @param attachments attachments
     * @throws Exception
     */
    protected void setAttachments(DocumentService documentService, Document document, InteractikCalendarEventEditionForm form) throws Exception {
        // Attachment files
        List<Attachment> files = form.getAttachments().getFiles();

        if (CollectionUtils.isNotEmpty(files)) {
            // Remove blobs
            SortedSet<Integer> removedIndexes = new TreeSet<>(this.indexComparator);
            for (Attachment file : files) {
                if (file.isDeleted() && (file.getIndex() != null)) {
                    removedIndexes.add(file.getIndex());
                }
            }
            for (Integer index : removedIndexes) {
                StringBuilder xpath = new StringBuilder();
                xpath.append(CalendarEventEditionRepository.ATTACHMENTS_PROPERTY);
                xpath.append("/item[");
                xpath.append(index);
                xpath.append("]");

                documentService.removeBlob(document, xpath.toString());
            }


            // Blobs
            List<Blob> blobs = new ArrayList<>(files.size());

            for (Attachment file : files) {
                // Temporary file
                File temporaryFile = file.getTemporaryFile();

                if (!file.isDeleted() && (temporaryFile != null)) {
                    // File name
                    String fileName = file.getTemporaryFileName();
                    // Mime type
                    String mimeType = file.getTemporaryMimeType().getBaseType();

                    // File blob
                    Blob blob = new FileBlob(temporaryFile, fileName, mimeType);

                    blobs.add(blob);
                }
            }

            if (!blobs.isEmpty()) {
                documentService.setBlobs(document, new Blobs(blobs), CalendarEventEditionRepository.ATTACHMENTS_PROPERTY);

                // Delete temporary files
                for (Attachment file : files) {
                    if (file.getTemporaryFile() != null) {
                        file.getTemporaryFile().delete();
                    }
                }
            }
        }
    }
    
    /**
     * Parse formatted date.
     * 
     * @param date formatted date
     * @return date object
     * @throws ParseException
     */
    private Date parseDate(String strDate) throws ParseException {
        StringBuilder source = new StringBuilder();
        source.append(StringUtils.trimToEmpty(strDate));
        Date date = null;
        if (source.length()>0) date = this.dateFormat.parse(source.toString());
        return date;
    }

}
